'use client';

import { useState } from 'react';
import Image from 'next/image';
import Link from 'next/link';


export default function Header() {
  const [isOpen, setIsOpen] = useState(false);

  return (
    <nav className="relative">
      <div className="container px-6 py-6 mx-auto">
        <div className="lg:flex lg:items-center lg:justify-between">
          {/* Left: Logo */}
          <div className="flex items-center justify-between lg:w-1/3">
            <a href="/">
              <Image
                src="/logo.png"
                alt="Logo"
                width={120}
                height={30}
              />
            </a>

            {/* Mobile menu button */}
            <div className="flex lg:hidden">
              <button
                onClick={() => setIsOpen(!isOpen)}
                type="button"
                className="focus:outline-none"
                aria-label="toggle menu"
              >
                {isOpen ? (
                  <svg xmlns="http://www.w3.org/2000/svg" className="w-6 h-6" fill="none"
                    viewBox="0 0 24 24" stroke="currentColor" strokeWidth={2}>
                    <path strokeLinecap="round" strokeLinejoin="round" d="M6 18L18 6M6 6l12 12" />
                  </svg>
                ) : (
                  <svg xmlns="http://www.w3.org/2000/svg" className="w-6 h-6" fill="none"
                    viewBox="0 0 24 24" stroke="currentColor" strokeWidth={2}>
                    <path strokeLinecap="round" strokeLinejoin="round" d="M4 8h16M4 16h16" />
                  </svg>
                )}
              </button>
            </div>
          </div>

          {/* Center: Navigation */}
          <div className={`lg:static lg:bg-transparent lg:w-2/3 lg:flex lg:justify-center lg:items-center ${isOpen ? 'block' : 'hidden'}`}>
            <div className="flex flex-col -mx-6 lg:flex-row lg:items-center lg:space-x-4 lg:mx-0 text-center bg-white py-2 px-[40px] lg:rounded-full">
              <Link href="/" className="px-3 py-2">Home</Link>
              <Link href="/about" className="px-3 py-2">
              About Us</Link>
              <Link href="/services" className="px-3 py-2">Services</Link>
              <Link href="/contact" className="px-3 py-2">Contact Us</Link>
            </div>
          </div>

          {/* Right: One Button */}
          <div className="hidden lg:flex justify-end lg:w-1/3">
            <Link href="/contact" className='button-blue'>
              Get Started
            </Link>
          </div>
        </div>
      </div>
    </nav>
  );
}
